@@ -7,10 +7,8 @@ from scipy import stats
 from svolfit.models.svol_model import svol_model
 from svolfit.models.Heston import Heston_tree,Heston_treeX2,Heston_grid
 
-from svolfit.models.model_utils import meanvariance
-
 from svolfit.models.Bates_utils import Bates_condassetprob_limitX2,Bates_lncondassetprob
-from svolfit.models.MertonJD_utils import sim_NormalJumps,moments_NormalJumps
+from svolfit.models.MertonJD_utils import sim_NormalJumps,moments_NormalJumps,MertonJD_calibratemoments
 from svolfit.models.Heston_utils import Heston_standardreturn
 
 
@@ -39,7 +37,8 @@ class Bates_tree(Heston_tree):
         lamb_lower = 0.01
         r_lower = 0.05
         if( len(self.series)>1 ):
-            (mu,sigma)=meanvariance(np.array(self.series),self.dt)
+            (mu,sigma,lamb,gamm,omeg)=MertonJD_calibratemoments(np.array(self.series),self.dt)
+            mu=0.0
             lamb_lower = 10/self.dt/len(self.series)
 
 # careful needs unscaled lambda:
@@ -270,6 +269,7 @@ class Bates_tree(Heston_tree):
 #        ret['u0']=u0
         ret['rep_v0']=v0
 
+        ret['misc_muj']=lamb*np.expm1(gamm+0.5*omeg*omeg)
 
         (V,S,K)=moments_NormalJumps(self.dt,sigma,lamb,gamm,omeg)
 
@@ -427,7 +427,7 @@ class Bates_treeX2(Heston_treeX2):
         lamb_lower = 0.01
         r_lower = 0.05
         if( len(self.series)>1 ):
-            (mu,sigma)=meanvariance(np.array(self.series),self.dt)
+            (mu,sigma,lamb,gamm,omeg)=MertonJD_calibratemoments(np.array(self.series),self.dt)
             mu = 0.0
 #            print(mu,sigma,lamb,gamm,omeg)
             lamb_lower = 10/self.dt/len(self.series)
@@ -702,6 +702,8 @@ class Bates_treeX2(Heston_treeX2):
         ret['sim_rep_omega']=sim_omeg
         ret['sim_rep_v0']=sim_v0
 
+        ret['misc_muj']=lamb*np.expm1(gamm+0.5*omeg*omeg)
+
         ret['misc_q']=q
 #        ret['uT']=uT
         ret['misc_vT']=vT
@@ -812,7 +814,7 @@ class Bates_grid(Heston_grid):
         lamb_lower = 0.01
         r_lower = 0.05
         if( len(self.series)>1 ):
-            (mu,sigma)=meanvariance(np.array(self.series),self.dt)
+            (mu,sigma,lamb,gamm,omeg)=MertonJD_calibratemoments(np.array(self.series),self.dt)
             mu = 0.0
 #            print(mu,sigma,lamb,gamm,omeg)
             lamb_lower = 10/self.dt/len(self.series)
@@ -1068,6 +1070,8 @@ class Bates_grid(Heston_grid):
         ret['sim_rep_omega']=sim_omeg
         ret['sim_rep_v0']=sim_v0
 
+        ret['misc_muj']=lamb*np.expm1(gamm+0.5*omeg*omeg)
+
         ret['misc_q']=q
 #        ret['uT']=uT
         ret['misc_vT']=vT
