@@ -4,12 +4,10 @@ import math
 from svolfit.models.svol_model import svol_model
 from svolfit.models.GARCHdiff import GARCHdiff_grid
 
-from svolfit.models.model_utils import meanvariance,logsumexp
-
 from svolfit.models.GARCHdiff_utils import GARCHdiff_griddefs
 from svolfit.models.GARCHjdiff_utils import GARCHjdiff_lncondassetprob
 from svolfit.models.Heston_utils import Heston_pathprob
-from svolfit.models.MertonJD_utils import sim_NormalJumps
+from svolfit.models.MertonJD_utils import sim_NormalJumps,MertonJD_calibratemoments
 
 
 #-------------------------------------
@@ -36,7 +34,7 @@ class GARCHjdiff_grid(GARCHdiff_grid):
         lamb_lower = 0.01
         r_lower = 0.05
         if( len(self.series)>1 ):
-            (mu,sigma)=meanvariance(np.array(self.series),self.dt)
+            (mu,sigma,lamb,gamm,omeg)=MertonJD_calibratemoments(np.array(self.series),self.dt)
             mu = 0.0
 #            print(mu,sigma,lamb,gamm,omeg)
             lamb_lower = 10/self.dt/len(self.series)
@@ -296,6 +294,8 @@ class GARCHjdiff_grid(GARCHdiff_grid):
         ret['sim_rep_omega']=sim_omeg
         ret['sim_rep_v0']=sim_v0
 
+        ret['misc_muj']=lamb*np.expm1(gamm+0.5*omeg*omeg)
+
         ret['misc_q']=q
 #        ret['uT']=uT
         ret['misc_vT']=vT
