@@ -1,6 +1,17 @@
 import numpy as np
 
 #-------------------------------------------------
+def GBM_meanvariance(asset,dt):
+    
+    rets=np.log(asset[1:len(asset)]/asset[0:len(asset)-1])
+    
+    sigma=np.std(rets,ddof=1)
+    mu=np.mean(rets)+0.5*sigma*sigma
+
+    mu = mu/dt
+    sigma=sigma/np.sqrt(dt)
+
+    return (mu,sigma)
 
 def GBM_lncondassetprob(y,dt,mu,sigma,lncp):
 
