@@ -21,12 +21,11 @@ class MertonJD_grid(svol_model):
         sigma=0.1
         lamb = 20.0/self.lamb_scaling
         gamm = 0.0
-        omeg = 0.02
+        omeg = 0.05
         lamb_upper = 504.0
         lamb_lower = 0.01
         r_lower = 0.05
         if( len(self.series)> 1 ):
-#            (mu,sigma)=meanvariance(np.array(self.series),self.dt)
             (mu,sigma,lamb,gamm,omeg)=MertonJD_calibratemoments(np.array(self.series),self.dt)
             mu = 0.0
 #            print(mu,sigma,lamb,gamm,omeg)
@@ -203,6 +202,8 @@ class MertonJD_grid(svol_model):
         ret['rep_gamma']=gamm
         ret['rep_omega']=omeg
 
+        ret['misc_muj']=lamb*np.expm1(gamm+0.5*omeg*omeg)
+
 #        ret['u0']=u0
 #        ret['uT']=uT
         ret['misc_theta']=theta
