@@ -1,6 +1,7 @@
 import numpy as np
 from scipy import stats
 from scipy import special
+from scipy import optimize
 import math
 
 from svolfit.models.model_utils import logsumexp
@@ -24,8 +25,9 @@ def sim_NormalJumps(dt,lamb,gamm,omeg,Zs,sim_asset):
 
     njumps=np.searchsorted(thresh,Zs[0,:,:])
  
-    bbar = np.expm1(gamm+0.5*omeg*omeg)
-    sim_asset+=-lamb*bbar*dt
+    muj = lamb*np.expm1(gamm+0.5*omeg*omeg)
+    sim_asset+=-muj*dt
+#    print(lamb,gamm,omeg,muj,dt,muj*dt)
 
     for cc in range(0,Nperstep):
         sim_asset+=gamm*njumps[cc,:]
@@ -111,40 +113,76 @@ def Constraint_JB_grad(workingpars,JBthreshold,dt,lamb_scaling):
 
 def MertonJD_calibratemoments(series,dt):
 	
-# simpler: set lambda=1, gamma = 0.0 and just fit r to kurtosis
+# 
     Nret=len(series)-1
     yasset=np.log( series[1:Nret+1]/series[0:Nret] )
 
-    mu=np.mean(yasset)/dt
+    m=np.mean(yasset)/dt
     V=stats.moment(yasset,moment=2)
+    m3=stats.moment(yasset,moment=3)
     m4=stats.moment(yasset,moment=4)
 
-    f1 = m4/(3.0*V*V)-1.0
+    Slim=2.0*6.0/np.sqrt(Nret)
+    Klim=2.0*24.0/np.sqrt(Nret)
 
-    gamm=0.0
-    lamb=1.0
+    S=m3/(V*np.sqrt(V))
+    K=m4/(V*V)-3.0
+#    print(m,V,m3,m4,S,K)
+
+    if( np.abs(S)<= Slim ): #assume S=0
+        K=np.maximum(Klim,K)# assures that lambda isn't overly large
+        lamb=1.0/K/dt
+        rsq=0.5*(1.0+np.sqrt(3.0))
+        r=np.sqrt(rsq)
+#        print(r)
+        
+        sigma=np.sqrt(V/dt/(1+rsq))
     
-    if( f1 <= 0.0 ):
-# tails aren't fat...
-        omeg=0.002
-        sigma = np.sqrt(V/dt)
-#        print(mu,sigma,lamb,gamm,omeg)
+        gamm=0.0
+        omeg=r*sigma/np.sqrt(lamb)
+#        print(gamm,omeg)
+        bbar = np.expm1(gamm+0.5*omeg*omeg)
+        mu=m+0.5*sigma*sigma+lamb*bbar
+    	
+#        print(S,K,mu,sigma,lamb,gamm,omeg)
+        
         return (mu,sigma,lamb,gamm,omeg)
 
-#recall that with a nonzero gamma a larger kurtosis is possible, so this can violate the naive bound:
-    pwr=np.minimum(1.0-1.0e-4,np.power(f1*lamb/3.0,0.25))
-#    print(pwr)
-    psi=np.arctanh( pwr )
-# sanity check no large r?
-    r=np.minimum(5.0,np.sinh(psi))
-    sigma = np.sqrt(V/dt)/np.sqrt(1.0+r*r)
-    omeg=sigma*r/np.sqrt(lamb)      
+# this all assumes that S is material        
+    K=np.maximum(Klim,K)# assures that lambda isn't overly large
 
+    lamb=1.0/K/dt
+    print(lamb)
+#solve
+#    x=np.sin(phi)**2
+    R1=S*S/K
+    R1=np.minimum(R1,1.0-1.0/101.0)
+
+    h = lambda x: 1.0-R1*R1*(3.0-2.0*x*x)*(3.0-2.0*x*x)*(3.0-2.0*x*x)/( x*x*(3.0-2.0*x)*(3.0-2.0*x)*(3.0-2.0*x)*(3.0-2.0*x) )
+    res = optimize.root_scalar(h, bracket=[1.0e-6,1.0], method='brentq')
+#    print(res)
+    x=res.root
+    phi=np.arcsin(np.sqrt(x))
+    if( S < 0.0 ):
+        phi = -phi
+#    print(S,K,R1,x,phi)
+    g = x*(3.0-2.0*x)*(3.0-2.0*x)/(3.0-2.0*x*x)
+    rsq=R1/(g-R1)
+#    print(rsq)
+
+    r=np.sqrt(rsq)
+#    print(r)
+    
+    sigma=np.sqrt(V/dt/(1+rsq))
+
+    gamm=r*sigma*np.sin(phi)/np.sqrt(lamb)
+    omeg=r*sigma*np.cos(phi)/np.sqrt(lamb)
+#    print(gamm,omeg)
     bbar = np.expm1(gamm+0.5*omeg*omeg)
-    mu=mu+0.5*sigma*sigma+lamb*bbar
+    mu=m+0.5*sigma*sigma+lamb*bbar
 	
-#    print(mu,sigma,lamb,gamm,omeg)
-
+#    print(S,K,mu,sigma,lamb,gamm,omeg)
+    
     return (mu,sigma,lamb,gamm,omeg)
 
 
