@@ -23,8 +23,8 @@ class Template(svol_model):
         ret={}
         return ret
 
-    def workingpars_update(self,workingpars):
-        super().workingpars_update(workingpars)
+    def update(self):
+        super().update()
         return
 
     def calculate(self):
@@ -34,5 +34,12 @@ class Template(svol_model):
     def variancepath(self):
         return 
     
-    
+    def status(self):
+        if self.current != True:
+            return 'Failure','Incorrect Model State.'
+
+        status = 'Success'
+        message = 'No issues.'        
+        return (status,message)
+
     
\ No newline at end of file
